@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-10-03'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -244,11 +244,11 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.10 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-09-03.
+This document describes version 0.11 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-03.
 
 =head1 SEE ALSO
 
-L<App::FatPack>, L<App::fatten>
+L<App::FatPack>, L<App::depak>
 
 L<Data::Section::Seekable>, the format used for the data section
 
@@ -277,6 +277,8 @@ section is not yet available. You can only use run-time require()'s.
 Another downside of this technique is that you cannot use C<__DATA__> section for
 other purposes (well, actually with some care, you still can).
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
